==> DateTime-Locale-1.36.tar.gz: DateTime-Locale-1.36/share/om-KE.pl <==
{
  am_pm_abbreviated => [
    "WD",
    "WB",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'week' W 'of' MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMMdd => "dd MMMM",
    MMMd => "MMM d",
    MMdd => "dd/MM",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMM => "MM/y",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "om-KE",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "dd MMMM y",
  date_format_medium => "dd-MMM-y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Wix",
    "Qib",
    "Rob",
    "Kam",
    "Jim",
    "San",
    "Dil",
  ],
  day_format_narrow => [
    "W",
    "Q",
    "R",
    "K",
    "J",
    "S",
    "D",
  ],
  day_format_wide => [
    "Wiixata",
    "Qibxata",
    "Roobii",
    "Kamiisa",
    "Jimaata",
    "Sanbata",
    "Dilbata",
  ],
  day_stand_alone_abbreviated => [
    "Wix",
    "Qib",
    "Rob",
    "Kam",
    "Jim",
    "San",
    "Dil",
  ],
  day_stand_alone_narrow => [
    "W",
    "Q",
    "R",
    "K",
    "J",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "Wiixata",
    "Qibxata",
    "Roobii",
    "Kamiisa",
    "Jimaata",
    "Sanbata",
    "Dilbata",
  ],
  era_abbreviated => [
    "KD",
    "CE",
  ],
  era_narrow => [
    "KD",
    "CE",
  ],
  era_wide => [
    "Dheengadda Jeesu",
    "CE",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Oromo",
  month_format_abbreviated => [
    "Ama",
    "Gur",
    "Bit",
    "Elb",
    "Cam",
    "Wax",
    "Ado",
    "Hag",
    "Ful",
    "Onk",
    "Sad",
    "Mud",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Amajjii",
    "Guraandhala",
    "Bitooteessa",
    "Elba",
    "Caamsa",
    "Waxabajjii",
    "Adooleessa",
    "Hagayya",
    "Fuulbana",
    "Onkololeessa",
    "Sadaasa",
    "Muddee",
  ],
  month_stand_alone_abbreviated => [
    "Ama",
    "Gur",
    "Bit",
    "Elb",
    "Cam",
    "Wax",
    "Ado",
    "Hag",
    "Ful",
    "Onk",
    "Sad",
    "Mud",
  ],
  month_stand_alone_narrow => [
    "A",
    "G",
    "B",
    "E",
    "C",
    "W",
    "A",
    "H",
    "F",
    "O",
    "S",
    "M",
  ],
  month_stand_alone_wide => [
    "Amajjii",
    "Guraandhala",
    "Bitooteessa",
    "Elba",
    "Caamsa",
    "Waxabajjii",
    "Adooleessa",
    "Hagayya",
    "Fuulbana",
    "Onkololeessa",
    "Sadaasa",
    "Muddee",
  ],
  name => "Oromo Kenya",
  native_language => "Oromoo",
  native_name => "Oromoo Keeniyaa",
  native_script => undef,
  native_territory => "Keeniyaa",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kurmaana 1",
    "Kurmaana 2",
    "Kurmaana 3",
    "Kurmaana 4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kurmaana 1",
    "Kurmaana 2",
    "Kurmaana 3",
    "Kurmaana 4",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/om-KE.pl <==
{
  am_pm_abbreviated => [
    "WD",
    "WB",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMMdd => "dd MMMM",
    MMMd => "MMM d",
    MMdd => "dd/MM",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMM => "MM/y",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "om-KE",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "dd MMMM y",
  date_format_medium => "dd-MMM-y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Wix",
    "Qib",
    "Rob",
    "Kam",
    "Jim",
    "San",
    "Dil",
  ],
  day_format_narrow => [
    "W",
    "Q",
    "R",
    "K",
    "J",
    "S",
    "D",
  ],
  day_format_wide => [
    "Wiixata",
    "Qibxata",
    "Roobii",
    "Kamiisa",
    "Jimaata",
    "Sanbata",
    "Dilbata",
  ],
  day_stand_alone_abbreviated => [
    "Wix",
    "Qib",
    "Rob",
    "Kam",
    "Jim",
    "San",
    "Dil",
  ],
  day_stand_alone_narrow => [
    "W",
    "Q",
    "R",
    "K",
    "J",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "Wiixata",
    "Qibxata",
    "Roobii",
    "Kamiisa",
    "Jimaata",
    "Sanbata",
    "Dilbata",
  ],
  era_abbreviated => [
    "KD",
    "CE",
  ],
  era_narrow => [
    "KD",
    "CE",
  ],
  era_wide => [
    "Dheengadda Jeesu",
    "CE",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Oromo",
  month_format_abbreviated => [
    "Ama",
    "Gur",
    "Bit",
    "Elb",
    "Cam",
    "Wax",
    "Ado",
    "Hag",
    "Ful",
    "Onk",
    "Sad",
    "Mud",
  ],
  month_format_narrow => [
    "A",
    "G",
    "B",
    "E",
    "C",
    "W",
    "A",
    "H",
    "F",
    "O",
    "S",
    "M",
  ],
  month_format_wide => [
    "Amajjii",
    "Guraandhala",
    "Bitooteessa",
    "Elba",
    "Caamsa",
    "Waxabajjii",
    "Adooleessa",
    "Hagayya",
    "Fuulbana",
    "Onkololeessa",
    "Sadaasa",
    "Muddee",
  ],
  month_stand_alone_abbreviated => [
    "Ama",
    "Gur",
    "Bit",
    "Elb",
    "Cam",
    "Wax",
    "Ado",
    "Hag",
    "Ful",
    "Onk",
    "Sad",
    "Mud",
  ],
  month_stand_alone_narrow => [
    "A",
    "G",
    "B",
    "E",
    "C",
    "W",
    "A",
    "H",
    "F",
    "O",
    "S",
    "M",
  ],
  month_stand_alone_wide => [
    "Amajjii",
    "Guraandhala",
    "Bitooteessa",
    "Elba",
    "Caamsa",
    "Waxabajjii",
    "Adooleessa",
    "Hagayya",
    "Fuulbana",
    "Onkololeessa",
    "Sadaasa",
    "Muddee",
  ],
  name => "Oromo Kenya",
  native_language => "Oromoo",
  native_name => "Oromoo Keeniyaa",
  native_script => undef,
  native_territory => "Keeniyaa",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kurmaana 1",
    "Kurmaana 2",
    "Kurmaana 3",
    "Kurmaana 4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kurmaana 1",
    "Kurmaana 2",
    "Kurmaana 3",
    "Kurmaana 4",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
